Crate timelapse

A simple profiler for Rust applications.

This crate provides a basic profiling utility that can be used to measure the elapsed time of code execution.

The TimeLapse profiler is open-source and can be freely used and modified under the terms of the MIT license.

Modules

profiler
A simple profiler for measuring elapsed time in Rust.

Macros

profile_end
The profile_end! macro logs the elapsed time of the profiling instance created by profile_start!. These macros are useful for quick profiling without needing to manually create and manage TimeLapse instances.
profile_start
The profile_start! macro initializes a TimeLapse instance to start profiling. It takes an identifier as an argument, which will be used to reference the profiler instance.